Типы данных — СпамоБорец: документация

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- API СпамоБорца »

# Типы данных

## Partner

Информация о партнере, относительно которого должна выполняться данная команда. Партнер авторизует вызов API.

Информация, передаваемая в этом параметре, зависит от текущего механизма авторизации партнеров, для доверительного механизма авторизации это всегда `null` (или `None`, `nil`, в зависимости от языка программирования и способа сериализации).

## Domain

Путь к домену, относительного которого будет происходить выполнение команды. Путь задается относительного корневого домена текущего партнера.

Если параметр не задан, равен `""` или `"/"`, команда исполняется относительного корневого домена партнера. Если параметр равен, например, `"a/b"`, команда исполняется в поддомене `b` поддомена `a` корневого домена текущего партнера.

## Message

Сериализованное представление сообщения при передаче в API СпамоБорца. Данный тип данных - это хэш, ключами которого являются имена атрибутов сообщения, а значениями - значения этих атрибутов, сериализованные относительно соответствующих доменов атрибутов. Десериализация сообщения выполняется всегда относительного выбранного домена, при этом осуществляется поиск по имени домена атрибута в домене сообщения и десериализация в соответствующий атрибут сообщения.

Например, пусть в параметре `messageDomain` текущего домена хранится такой домен сообщения:

    MessageDomain(TextAttributeDomain("text"), UniqueIntAttributeDomain("from"))

Тогда относительно данного домена будут валидными следующие сериализованные сообщения:

    { }
    { 'text' : 'Is this SPAM?' }
    { 'text' : 'It is beatiful!', 'from' : 137 }

А следующие сериализованные сообщения не будут валидны:

    { 'ip' : '127.0.0.1' }         /* неизвестный атрибут 'ip' */
    { 'from' : '127' }             /* неверный тип данных для атрибута 'from' */

## LogEntry

Отдельная запись в логе сообщений, сериализованная для передачи через API СпамоБорца. Данный тип данных представляет собой хэш с следующими ключами:

`id`
  `integer` ID записи в логе сообщений (уникально относительно лога сообщений)

`when`
  `integer` дата и время попадания записи в лог, время в секундах с 1 января 1970 г., UTC

`tags`
  `Array(string)` список тэгов, сохраненных в логе вместе с сообщением

`message`
  Message сохраненное в логе сообщение

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- API СпамоБорца »